/*
 * Copyright (c) 2011 - 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __SHORTCUT_PRIVATE_H__
#define __SHORTCUT_PRIVATE_H__

#include <system_info.h>

#if !defined(FLOG)
#define SHORTCUT_DBG(format, arg...)	SECURE_LOGD(format, ##arg)
#define SHORTCUT_ERR(format, arg...)	SECURE_LOGE(format, ##arg)
#define SHORTCUT_INFO(format, arg...)	SECURE_LOGI(format, ##arg)
#else
extern FILE *__file_log_fp;
#define SHORTCUT_DBG(format, arg...) do { fprintf(__file_log_fp, "[D] [[32m%s/%s[0m:%d] " format, basename(__FILE__), __func__, __LINE__, ##arg); fflush(__file_log_fp); } while (0)
#define SHORTCUT_ERR(format, arg...) do { fprintf(__file_log_fp, "[E] [[32m%s/%s[0m:%d] " format, basename(__FILE__), __func__, __LINE__, ##arg); fflush(__file_log_fp); } while (0)
#define SHORTCUT_INFO(format, arg...) do { fprintf(__file_log_fp, "[I] [[32m%s/%s[0m:%d] " format, basename(__FILE__), __func__, __LINE__, ##arg); fflush(__file_log_fp); } while (0)
#endif

#if !defined(EAPI)
#define EAPI __attribute__((visibility("default")))
#endif

#define DEFAULT_ICON_LAYOUT ""
#define DEFAULT_ICON_GROUP ""

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define SHORTCUT_FEATURE "http://tizen.org/feature/shortcut"
#define CHECK_SHORTCUT_FEATURE() \
	do { \
		bool is_supported = false; \
		if (!system_info_get_platform_bool(SHORTCUT_FEATURE, &is_supported)) { \
			if (is_supported == false) { \
				LOGE("[%s] feature is disabled", SHORTCUT_FEATURE); \
				return SHORTCUT_ERROR_NOT_SUPPORTED; \
			} \
		} \
	} while (0)

#define CHECK_SHORTCUT_FEATURE_RET_LAST_RESULT() \
	do { \
		bool is_supported = false; \
		if (!system_info_get_platform_bool(SHORTCUT_FEATURE, &is_supported)) { \
			if (is_supported == false) { \
				LOGE("[%s] feature is disabled", SHORTCUT_FEATURE); \
				set_last_result(SHORTCUT_ERROR_NOT_SUPPORTED); \
				return; \
			} \
		} \
	} while (0)
#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __SHORTCUT_PRIVATE_H__ */

/* End of a file */
